<template>
  <div class="container">
    <h1 class="fs-3 fl-4">Service Sign Out</h1>
    <p class="fl-5">
      <p>Are you sure to sign out?</p>
      <div class="mt-8 actions">
        <button class="mr-4 btn btn-danger" type="button" @click="signOut" :disabled="state.$waiting" >
          <span v-if="state.$waiting" class="spinner-border spinner-border-sm" role="status" aria-hidden="true"></span> Sign Out
        </button>
        <button class="btn btn-secondary" type="button" @click="cancel">Cancel</button>
      </div>
    </p>
  </div>
</template>



<script setup>
const router = useRouter ()
const { state } = useStore ()

function cancel () {
  router.back ()
}

async function signOut () {
  state.$waiting = true
  try {
    const auth = await firebase.getAuth ()
    firebase.auth.signOut (auth)
  } catch (error) {
    return frontend.handle_firebase_error (error, "Sign Out")
  }
  backend.remove_access_and_refresh_tokens ()

  state.$waiting = false
  bootstrap.toast ({title: "Success", text: "You have successfully signed out."})
  router.push ("/")
}

onActivated (() => {
  frontend.set_title ()
})

</script>

<script>
export default {
  beforeRouteEnter (to, from, next) {
    frontend.permission.required (['user'], {path: '/members/signin'}, {to, from, next})
  }
}
</script>